@@ -1,6 +1,7 @@
 #![deny(future_incompatible)]
 #![warn(nonstandard_style, rust_2018_idioms, missing_docs, clippy::pedantic)]
 #![deny(unsafe_code)]
+#![allow(clippy::wildcard_imports)]
 #![cfg_attr(not(feature = "std"), no_std)]
 #![cfg_attr(nightly, feature(doc_auto_cfg))]
 
@@ -180,3 +181,8 @@ trait Support {
 impl bevy_ecs_06::prelude::Component for CollisionShape {
     type Storage = bevy_ecs_06::component::SparseStorage;
 }
+
+#[cfg(feature = "bevy-ecs-07")]
+impl bevy_ecs_07::prelude::Component for CollisionShape {
+    type Storage = bevy_ecs_07::component::SparseStorage;
+}
