@@ -33,6 +33,10 @@ use impacted::{CollisionShape, Transform};
     CollisionShape::new_circle(1.0),
     CollisionShape::new_rectangle(2.0, 2.0).with_transform(Transform::from_angle_translation(consts::FRAC_PI_4, Vec2::X * 2.3)),
 )]
+#[case(
+    CollisionShape::new_circle(1.0),
+    CollisionShape::new_segment(Vec2::ZERO, Vec2::X)
+)]
 fn collides(#[case] shape1: CollisionShape, #[case] shape2: CollisionShape) {
     assert!(shape1.is_collided_with(&shape2))
 }
@@ -41,7 +45,6 @@ fn collides(#[case] shape1: CollisionShape, #[case] shape2: CollisionShape) {
 #[case(
     CollisionShape::new_circle(1.0),
     CollisionShape::new_circle(1.0).with_transform(Transform::from_translation(Vec2::X * 2.1)),
-
 )]
 #[case(
     CollisionShape::new_circle(1.0),
@@ -55,6 +58,10 @@ fn collides(#[case] shape1: CollisionShape, #[case] shape2: CollisionShape) {
     CollisionShape::new_circle(1.0),
     CollisionShape::new_rectangle(2.0, 2.0).with_transform(Transform::from_angle_translation(consts::FRAC_PI_4, Vec2::X * 2.5)),
 )]
+#[case(
+    CollisionShape::new_circle(1.0),
+    CollisionShape::new_segment(Vec2::X * 2.0, Vec2::X * 3.0),
+)]
 fn does_not_collide(#[case] shape1: CollisionShape, #[case] shape2: CollisionShape) {
     assert!(!shape1.is_collided_with(&shape2))
 }
